@@ -4,9 +4,9 @@ Main interface for codebuild service type definitions.
 Usage::
 
     ```python
-    from mypy_boto3_codebuild.type_defs import BuildArtifactsTypeDef
+    from mypy_boto3_codebuild.type_defs import BatchRestrictionsTypeDef
 
-    data: BuildArtifactsTypeDef = {...}
+    data: BatchRestrictionsTypeDef = {...}
     ```
 """
 import sys
@@ -25,12 +25,19 @@ else:
 
 
 __all__ = (
+    "BatchRestrictionsTypeDef",
     "BuildArtifactsTypeDef",
+    "BuildBatchPhaseTypeDef",
+    "BuildBatchTypeDef",
+    "BuildGroupTypeDef",
     "BuildNotDeletedTypeDef",
     "BuildPhaseTypeDef",
     "BuildStatusConfigTypeDef",
+    "BuildSummaryTypeDef",
     "BuildTypeDef",
     "CloudWatchLogsConfigTypeDef",
+    "CodeCoverageReportSummaryTypeDef",
+    "CodeCoverageTypeDef",
     "DebugSessionTypeDef",
     "EnvironmentImageTypeDef",
     "EnvironmentLanguageTypeDef",
@@ -44,6 +51,7 @@ __all__ = (
     "PhaseContextTypeDef",
     "ProjectArtifactsTypeDef",
     "ProjectBadgeTypeDef",
+    "ProjectBuildBatchConfigTypeDef",
     "ProjectCacheTypeDef",
     "ProjectEnvironmentTypeDef",
     "ProjectFileSystemLocationTypeDef",
@@ -54,6 +62,7 @@ __all__ = (
     "ReportExportConfigTypeDef",
     "ReportGroupTypeDef",
     "ReportTypeDef",
+    "ResolvedArtifactTypeDef",
     "S3LogsConfigTypeDef",
     "S3ReportExportConfigTypeDef",
     "SourceAuthTypeDef",
@@ -65,17 +74,23 @@ __all__ = (
     "WebhookFilterTypeDef",
     "WebhookTypeDef",
     "BatchDeleteBuildsOutputTypeDef",
+    "BatchGetBuildBatchesOutputTypeDef",
     "BatchGetBuildsOutputTypeDef",
     "BatchGetProjectsOutputTypeDef",
     "BatchGetReportGroupsOutputTypeDef",
     "BatchGetReportsOutputTypeDef",
+    "BuildBatchFilterTypeDef",
     "CreateProjectOutputTypeDef",
     "CreateReportGroupOutputTypeDef",
     "CreateWebhookOutputTypeDef",
+    "DeleteBuildBatchOutputTypeDef",
     "DeleteSourceCredentialsOutputTypeDef",
+    "DescribeCodeCoveragesOutputTypeDef",
     "DescribeTestCasesOutputTypeDef",
     "GetResourcePolicyOutputTypeDef",
     "ImportSourceCredentialsOutputTypeDef",
+    "ListBuildBatchesForProjectOutputTypeDef",
+    "ListBuildBatchesOutputTypeDef",
     "ListBuildsForProjectOutputTypeDef",
     "ListBuildsOutputTypeDef",
     "ListCuratedEnvironmentImagesOutputTypeDef",
@@ -89,7 +104,11 @@ __all__ = (
     "PaginatorConfigTypeDef",
     "PutResourcePolicyOutputTypeDef",
     "ReportFilterTypeDef",
+    "RetryBuildBatchOutputTypeDef",
+    "RetryBuildOutputTypeDef",
+    "StartBuildBatchOutputTypeDef",
     "StartBuildOutputTypeDef",
+    "StopBuildBatchOutputTypeDef",
     "StopBuildOutputTypeDef",
     "TestCaseFilterTypeDef",
     "UpdateProjectOutputTypeDef",
@@ -97,6 +116,12 @@ __all__ = (
     "UpdateWebhookOutputTypeDef",
 )
 
+BatchRestrictionsTypeDef = TypedDict(
+    "BatchRestrictionsTypeDef",
+    {"maximumBuildsAllowed": int, "computeTypesAllowed": List[str]},
+    total=False,
+)
+
 BuildArtifactsTypeDef = TypedDict(
     "BuildArtifactsTypeDef",
     {
@@ -110,6 +135,79 @@ BuildArtifactsTypeDef = TypedDict(
     total=False,
 )
 
+BuildBatchPhaseTypeDef = TypedDict(
+    "BuildBatchPhaseTypeDef",
+    {
+        "phaseType": Literal[
+            "SUBMITTED",
+            "DOWNLOAD_BATCHSPEC",
+            "IN_PROGRESS",
+            "COMBINE_ARTIFACTS",
+            "SUCCEEDED",
+            "FAILED",
+            "STOPPED",
+        ],
+        "phaseStatus": Literal[
+            "SUCCEEDED", "FAILED", "FAULT", "TIMED_OUT", "IN_PROGRESS", "STOPPED"
+        ],
+        "startTime": datetime,
+        "endTime": datetime,
+        "durationInSeconds": int,
+        "contexts": List["PhaseContextTypeDef"],
+    },
+    total=False,
+)
+
+BuildBatchTypeDef = TypedDict(
+    "BuildBatchTypeDef",
+    {
+        "id": str,
+        "arn": str,
+        "startTime": datetime,
+        "endTime": datetime,
+        "currentPhase": str,
+        "buildBatchStatus": Literal[
+            "SUCCEEDED", "FAILED", "FAULT", "TIMED_OUT", "IN_PROGRESS", "STOPPED"
+        ],
+        "sourceVersion": str,
+        "resolvedSourceVersion": str,
+        "projectName": str,
+        "phases": List["BuildBatchPhaseTypeDef"],
+        "source": "ProjectSourceTypeDef",
+        "secondarySources": List["ProjectSourceTypeDef"],
+        "secondarySourceVersions": List["ProjectSourceVersionTypeDef"],
+        "artifacts": "BuildArtifactsTypeDef",
+        "secondaryArtifacts": List["BuildArtifactsTypeDef"],
+        "cache": "ProjectCacheTypeDef",
+        "environment": "ProjectEnvironmentTypeDef",
+        "serviceRole": str,
+        "logConfig": "LogsConfigTypeDef",
+        "buildTimeoutInMinutes": int,
+        "queuedTimeoutInMinutes": int,
+        "complete": bool,
+        "initiator": str,
+        "vpcConfig": "VpcConfigTypeDef",
+        "encryptionKey": str,
+        "buildBatchNumber": int,
+        "fileSystemLocations": List["ProjectFileSystemLocationTypeDef"],
+        "buildBatchConfig": "ProjectBuildBatchConfigTypeDef",
+        "buildGroups": List["BuildGroupTypeDef"],
+    },
+    total=False,
+)
+
+BuildGroupTypeDef = TypedDict(
+    "BuildGroupTypeDef",
+    {
+        "identifier": str,
+        "dependsOn": List[str],
+        "ignoreFailure": bool,
+        "currentBuildSummary": "BuildSummaryTypeDef",
+        "priorBuildSummaryList": List["BuildSummaryTypeDef"],
+    },
+    total=False,
+)
+
 BuildNotDeletedTypeDef = TypedDict(
     "BuildNotDeletedTypeDef", {"id": str, "statusCode": str}, total=False
 )
@@ -145,6 +243,20 @@ BuildStatusConfigTypeDef = TypedDict(
     "BuildStatusConfigTypeDef", {"context": str, "targetUrl": str}, total=False
 )
 
+BuildSummaryTypeDef = TypedDict(
+    "BuildSummaryTypeDef",
+    {
+        "arn": str,
+        "requestedOn": datetime,
+        "buildStatus": Literal[
+            "SUCCEEDED", "FAILED", "FAULT", "TIMED_OUT", "IN_PROGRESS", "STOPPED"
+        ],
+        "primaryArtifact": "ResolvedArtifactTypeDef",
+        "secondaryArtifacts": List["ResolvedArtifactTypeDef"],
+    },
+    total=False,
+)
+
 BuildTypeDef = TypedDict(
     "BuildTypeDef",
     {
@@ -181,6 +293,7 @@ BuildTypeDef = TypedDict(
         "reportArns": List[str],
         "fileSystemLocations": List["ProjectFileSystemLocationTypeDef"],
         "debugSession": "DebugSessionTypeDef",
+        "buildBatchArn": str,
     },
     total=False,
 )
@@ -199,6 +312,36 @@ class CloudWatchLogsConfigTypeDef(
     pass
 
 
+CodeCoverageReportSummaryTypeDef = TypedDict(
+    "CodeCoverageReportSummaryTypeDef",
+    {
+        "lineCoveragePercentage": float,
+        "linesCovered": int,
+        "linesMissed": int,
+        "branchCoveragePercentage": float,
+        "branchesCovered": int,
+        "branchesMissed": int,
+    },
+    total=False,
+)
+
+CodeCoverageTypeDef = TypedDict(
+    "CodeCoverageTypeDef",
+    {
+        "id": str,
+        "reportARN": str,
+        "filePath": str,
+        "lineCoveragePercentage": float,
+        "linesCovered": int,
+        "linesMissed": int,
+        "branchCoveragePercentage": float,
+        "branchesCovered": int,
+        "branchesMissed": int,
+        "expired": datetime,
+    },
+    total=False,
+)
+
 DebugSessionTypeDef = TypedDict(
     "DebugSessionTypeDef", {"sessionEnabled": bool, "sessionTarget": str}, total=False
 )
@@ -314,6 +457,17 @@ ProjectBadgeTypeDef = TypedDict(
     "ProjectBadgeTypeDef", {"badgeEnabled": bool, "badgeRequestUrl": str}, total=False
 )
 
+ProjectBuildBatchConfigTypeDef = TypedDict(
+    "ProjectBuildBatchConfigTypeDef",
+    {
+        "serviceRole": str,
+        "combineArtifacts": bool,
+        "restrictions": "BatchRestrictionsTypeDef",
+        "timeoutInMins": int,
+    },
+    total=False,
+)
+
 _RequiredProjectCacheTypeDef = TypedDict(
     "_RequiredProjectCacheTypeDef", {"type": Literal["NO_CACHE", "S3", "LOCAL"]}
 )
@@ -448,6 +602,7 @@ ProjectTypeDef = TypedDict(
         "badge": "ProjectBadgeTypeDef",
         "logsConfig": "LogsConfigTypeDef",
         "fileSystemLocations": List["ProjectFileSystemLocationTypeDef"],
+        "buildBatchConfig": "ProjectBuildBatchConfigTypeDef",
     },
     total=False,
 )
@@ -471,7 +626,7 @@ ReportGroupTypeDef = TypedDict(
     {
         "arn": str,
         "name": str,
-        "type": Literal["TEST"],
+        "type": Literal["TEST", "CODE_COVERAGE"],
         "exportConfig": "ReportExportConfigTypeDef",
         "created": datetime,
         "lastModified": datetime,
@@ -484,7 +639,7 @@ ReportTypeDef = TypedDict(
     "ReportTypeDef",
     {
         "arn": str,
-        "type": Literal["TEST"],
+        "type": Literal["TEST", "CODE_COVERAGE"],
         "name": str,
         "reportGroupArn": str,
         "executionId": str,
@@ -494,10 +649,17 @@ ReportTypeDef = TypedDict(
         "exportConfig": "ReportExportConfigTypeDef",
         "truncated": bool,
         "testSummary": "TestReportSummaryTypeDef",
+        "codeCoverageSummary": "CodeCoverageReportSummaryTypeDef",
     },
     total=False,
 )
 
+ResolvedArtifactTypeDef = TypedDict(
+    "ResolvedArtifactTypeDef",
+    {"type": Literal["CODEPIPELINE", "S3", "NO_ARTIFACTS"], "location": str, "identifier": str},
+    total=False,
+)
+
 _RequiredS3LogsConfigTypeDef = TypedDict(
     "_RequiredS3LogsConfigTypeDef", {"status": Literal["ENABLED", "DISABLED"]}
 )
@@ -594,6 +756,7 @@ WebhookTypeDef = TypedDict(
         "secret": str,
         "branchFilter": str,
         "filterGroups": List[List["WebhookFilterTypeDef"]],
+        "buildType": Literal["BUILD", "BUILD_BATCH"],
         "lastModifiedSecret": datetime,
     },
     total=False,
@@ -605,6 +768,12 @@ BatchDeleteBuildsOutputTypeDef = TypedDict(
     total=False,
 )
 
+BatchGetBuildBatchesOutputTypeDef = TypedDict(
+    "BatchGetBuildBatchesOutputTypeDef",
+    {"buildBatches": List["BuildBatchTypeDef"], "buildBatchesNotFound": List[str]},
+    total=False,
+)
+
 BatchGetBuildsOutputTypeDef = TypedDict(
     "BatchGetBuildsOutputTypeDef",
     {"builds": List["BuildTypeDef"], "buildsNotFound": List[str]},
@@ -629,6 +798,12 @@ BatchGetReportsOutputTypeDef = TypedDict(
     total=False,
 )
 
+BuildBatchFilterTypeDef = TypedDict(
+    "BuildBatchFilterTypeDef",
+    {"status": Literal["SUCCEEDED", "FAILED", "FAULT", "TIMED_OUT", "IN_PROGRESS", "STOPPED"]},
+    total=False,
+)
+
 CreateProjectOutputTypeDef = TypedDict(
     "CreateProjectOutputTypeDef", {"project": "ProjectTypeDef"}, total=False
 )
@@ -641,10 +816,26 @@ CreateWebhookOutputTypeDef = TypedDict(
     "CreateWebhookOutputTypeDef", {"webhook": "WebhookTypeDef"}, total=False
 )
 
+DeleteBuildBatchOutputTypeDef = TypedDict(
+    "DeleteBuildBatchOutputTypeDef",
+    {
+        "statusCode": str,
+        "buildsDeleted": List[str],
+        "buildsNotDeleted": List["BuildNotDeletedTypeDef"],
+    },
+    total=False,
+)
+
 DeleteSourceCredentialsOutputTypeDef = TypedDict(
     "DeleteSourceCredentialsOutputTypeDef", {"arn": str}, total=False
 )
 
+DescribeCodeCoveragesOutputTypeDef = TypedDict(
+    "DescribeCodeCoveragesOutputTypeDef",
+    {"nextToken": str, "codeCoverages": List["CodeCoverageTypeDef"]},
+    total=False,
+)
+
 DescribeTestCasesOutputTypeDef = TypedDict(
     "DescribeTestCasesOutputTypeDef",
     {"nextToken": str, "testCases": List["TestCaseTypeDef"]},
@@ -659,6 +850,14 @@ ImportSourceCredentialsOutputTypeDef = TypedDict(
     "ImportSourceCredentialsOutputTypeDef", {"arn": str}, total=False
 )
 
+ListBuildBatchesForProjectOutputTypeDef = TypedDict(
+    "ListBuildBatchesForProjectOutputTypeDef", {"ids": List[str], "nextToken": str}, total=False
+)
+
+ListBuildBatchesOutputTypeDef = TypedDict(
+    "ListBuildBatchesOutputTypeDef", {"ids": List[str], "nextToken": str}, total=False
+)
+
 ListBuildsForProjectOutputTypeDef = TypedDict(
     "ListBuildsForProjectOutputTypeDef", {"ids": List[str], "nextToken": str}, total=False
 )
@@ -719,10 +918,26 @@ ReportFilterTypeDef = TypedDict(
     total=False,
 )
 
+RetryBuildBatchOutputTypeDef = TypedDict(
+    "RetryBuildBatchOutputTypeDef", {"buildBatch": "BuildBatchTypeDef"}, total=False
+)
+
+RetryBuildOutputTypeDef = TypedDict(
+    "RetryBuildOutputTypeDef", {"build": "BuildTypeDef"}, total=False
+)
+
+StartBuildBatchOutputTypeDef = TypedDict(
+    "StartBuildBatchOutputTypeDef", {"buildBatch": "BuildBatchTypeDef"}, total=False
+)
+
 StartBuildOutputTypeDef = TypedDict(
     "StartBuildOutputTypeDef", {"build": "BuildTypeDef"}, total=False
 )
 
+StopBuildBatchOutputTypeDef = TypedDict(
+    "StopBuildBatchOutputTypeDef", {"buildBatch": "BuildBatchTypeDef"}, total=False
+)
+
 StopBuildOutputTypeDef = TypedDict("StopBuildOutputTypeDef", {"build": "BuildTypeDef"}, total=False)
 
 TestCaseFilterTypeDef = TypedDict("TestCaseFilterTypeDef", {"status": str}, total=False)
